LocalAnomalyScore
=======================================================

.. currentmodule:: skchange.anomaly_scores

.. autoclass:: LocalAnomalyScore

.. include:: skchange.anomaly_scores.LocalAnomalyScore.examples

.. raw:: html

    <div class="clearer"></div>